# -*- coding: utf-8 -*-
"""
	Coins
    ~~~~~

    :copyright: (c) 2013 by Halfmoon Labs
    :license: MIT, see LICENSE for more details.
"""

__version__ = '0.1'

from .wallets import BitcoinWallet, LitecoinWallet, NamecoinWallet, \
	PeercoinWallet, PrimecoinWallet
